
def generate_random_sequence(input_sequence, num_steps, layer_type='LSTM', return_sequences=False):
    from keras.layers import Layer, RepeatVector, TimeDistributed
    from keras.models import Sequential
    from keras.layers.recurrent import LSTM

    class RandomSequenceGenerator(Layer):
        def __init__(self, num_steps, output_dim, layer_type='LSTM', **kwargs):
            self.num_steps = num_steps
            self.output_dim = output_dim
            self.layer_type = layer_type
            super(RandomSequenceGenerator, self).__init__(**kwargs)

        def build(self, input_shape):
            self.kernel = self.add_weight(name='kernel', 
                                          shape=(input_shape[1], self.output_dim),
                                          initializer='uniform',
                                          trainable=True)
            if self.layer_type == 'LSTM':
                self.repeater = RepeatVector(self.num_steps)
                self.tdist = TimeDistributed(LSTM(self.output_dim))
            super(RandomSequenceGenerator, self).build(input_shape)

        def call(self, x):
            x = self.repeater(x)
            x = self.tdist(x)
            return x

    model = Sequential()
    model.add(RandomSequenceGenerator(num_steps=num_steps, output_dim=input_sequence.shape[1], layer_type=layer_type, return_sequences=return_sequences))
    return model



